# abqcy documentation

Write Abaqus Subroutines in Cython.

- GitHub repository: <https://github.com/haiiliin/abqcy>
- PyPI: <https://pypi.org/project/abqcy>
- Documentation: <https://abqcy.readthedocs.io>
- Read the Docs: <https://readthedocs.org/projects/abqcy>
- Bug report: <https://github.com/haiiliin/abqcy/issues>

## Table of Contents

```{toctree}
:caption: Contents
:maxdepth: 1

getting-started
examples
cli
autoapi/index
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
